@@ -127,7 +127,7 @@ public:
     void writeConfig(KConfigGroup &config);
 
 protected:
-    void updateConfig();
+    void updateConfig() Q_DECL_OVERRIDE;
 
 public:
     KEncodingProber::ProberType proberType() const
@@ -191,7 +191,7 @@ public:
     void writeConfig(KConfigGroup &config);
 
 protected:
-    void updateConfig();
+    void updateConfig() Q_DECL_OVERRIDE;
 
 public:
     int tabWidth() const;
@@ -431,7 +431,7 @@ public:
     void writeConfig(KConfigGroup &config);
 
 protected:
-    void updateConfig();
+    void updateConfig() Q_DECL_OVERRIDE;
 
 public:
     bool dynWordWrap() const;
@@ -555,6 +555,9 @@ public:
     bool foldFirstLine() const;
     void setFoldFirstLine(bool on);
 
+    bool showWordCount();
+    void setShowWordCount(bool on);
+
 private:
     bool m_dynWordWrap;
     int m_dynWordWrapIndicators;
@@ -585,6 +588,7 @@ private:
     bool m_smartCopyCut;
     bool m_scrollPastEnd;
     bool m_foldFirstLine;
+    bool m_showWordCount;
 
     bool m_dynWordWrapSet : 1;
     bool m_dynWordWrapIndicatorsSet : 1;
@@ -664,7 +668,7 @@ public:
     void writeConfig(KConfigGroup &config);
 
 protected:
-    void updateConfig();
+    void updateConfig() Q_DECL_OVERRIDE;
 
 public:
     const QString &schema() const;
